@@ -15,7 +15,7 @@ _.fibonacci.restype = c.c_char_p
 
 
 def print_fib(term_count: int):
-    '''prints fibonacci series up to term_count'''
+    '''prints fibonacci series up to the term_count'''
 
     if not (isinstance(term_count, int) and term_count > 0):
         raise ValueError("'term_count' has to be bigger than 0 and 'int'.")
@@ -29,11 +29,7 @@ def factorial(term: int) -> int:
     if not (isinstance(term, int) and term >= 0):
         raise ValueError("'term' has to be bigger than 0 and 'int'.")
 
-    _result = _.factorial(term)
-    result = _result.value
-    _.free(_result)
-
-    return result
+    return int(_.factorial(term).decode('utf-8'))
 
 
 def fibonacci(term: int, precision: int = 1000) -> int:
@@ -42,11 +38,7 @@ def fibonacci(term: int, precision: int = 1000) -> int:
     if not (isinstance(term, int) and term >= 0):
         raise ValueError("'term' has to be bigger than 0 and 'int'.")
 
-    _result = _.fibonacci(term)
-    result = _result.value
-    _.free(_result)
-
-    return result
+    return int(_.fibonacci(term).decode('utf-8'))
 
 
 if __name__ == "__main__":
